@@ -1,7 +1,7 @@
 package HTML::FormHandler::Field::Reset;
 
 use Moose;
-extends 'HTML::FormHandler::Field::Display';
+extends 'HTML::FormHandler::Field::NoValue';
 
 =head1 NAME
 
@@ -17,6 +17,8 @@ Uses the 'reset' widget.
 
 =cut
 
+has '+widget' => ( default => 'reset' );
+
 has '+value' => ( default => 'Reset' );
 
 __PACKAGE__->meta->make_immutable;
