@@ -1,22 +1,23 @@
 package HTML::FormHandler::Widget::Field::Password;
 
 use Moose::Role;
+use namespace::autoclean;
+
 with 'HTML::FormHandler::Widget::Field::Role::HTMLAttributes';
 
 sub render {
-    my ( $self, $result ) = @_;
+    my $self = shift;
+    my $result = shift || $self->result;
+    my $t;
 
-    $result ||= $self->result;
-    my $output = '<input type="password" name="';
-    $output .= $self->html_name . '"';
-    $output .= ' id="' . $self->id . '"';
-    $output .= ' size="' . $self->size . '"' if $self->size;
-    $output .= ' maxlength="' . $self->maxlength . '"' if $self->maxlength;
+    my $output = '<input type="password" name="'
+        . $self->html_name . '" id="' . $self->id . '"';
+    $output .= qq{ size="$t"} if $t = $self->size;
+    $output .= qq{ maxlength="$t"} if $t = $self->maxlength;
     $output .= ' value="' . $self->html_filter($result->fif) . '"';
     $output .= $self->_add_html_attributes;
     $output .= ' />';
     return $self->wrap_field( $result, $output );
 }
 
-use namespace::autoclean;
 1;
